@@ -2,7 +2,7 @@
 # from/to	calBP		BCAD		C14			F14C		pMC			D14C	
 # calBP					calBPtoBCAD	calBPtoC14	calBPtoF14C	calBPtopMC	calBPtoD14C
 # BCAD		BCADtocalP				BCADtoC14	BCADtoF14C	BCADtopMC	BCADtoD14C
-# C14		NA			NA						C14toF14C	C14topMC	C14toD14C
+# C14		C14tocalBP	C14toBCAD				C14toF14C	C14topMC	C14toD14C
 # F14C		NA			NA			F14CtoC14				F14CtopMC	F14CtoD14C
 # pMC		NA			NA			pMCtoC14	pMCtoF14C				pMCtoD14C
 # D14C		NA			NA			D14CtoC14	D14CtoF14C	D14CtopMC
@@ -38,7 +38,7 @@ calBPtoBCAD <- function(x, zero=TRUE) {
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding 14C age and error are returned.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For negative cal BP ages, a postbomb curve will have to be provided.
 #' @return The calibration-curve 14C year belonging to the entered cal BP age
-#' @param yr The cal BP year.
+#' @param x The cal BP year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
@@ -48,12 +48,12 @@ calBPtoBCAD <- function(x, zero=TRUE) {
 #' @examples
 #' calBPtoC14(100)
 #' @export
-calBPtoC14 <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
+calBPtoC14 <- function(x, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
   if(is.null(thiscurve))
     cc <- rintcal::ccurve(cc=cc, postbomb=postbomb, cc.dir=cc.dir) else
       cc <- thiscurve
-  mu <- approx(cc[,1], cc[,2], yr, rule=rule)$y
-  er <- approx(cc[,1], cc[,3], yr, rule=rule)$y
+  mu <- approx(cc[,1], cc[,2], x, rule=rule)$y
+  er <- approx(cc[,1], cc[,3], x, rule=rule)$y
   return(cbind(mu, er, deparse.level=0))
 }
 
@@ -64,7 +64,7 @@ calBPtoC14 <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding F14C value and error are returned.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For negative cal BP ages, a postbomb curve will have to be provided.
 #' @return The calibration-curve 14C year belonging to the entered cal BP age
-#' @param yr The cal BP year.
+#' @param x The cal BP year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
@@ -74,8 +74,8 @@ calBPtoC14 <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=
 #' @examples
 #'   calBPtoF14C(100)
 #' @export
-calBPtoF14C <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
-  y <- calBPtoC14(yr, cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve)
+calBPtoF14C <- function(x, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
+  y <- calBPtoC14(x, cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve)
   return(C14toF14C(y[,1], y[,2]))
 }
 
@@ -86,7 +86,7 @@ calBPtoF14C <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding F14C value and error are returned.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For negative cal BP ages, a postbomb curve will have to be provided.
 #' @return The calibration-curve 14C year belonging to the entered cal BP age
-#' @param yr The cal BP year.
+#' @param x The cal BP year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
@@ -96,8 +96,8 @@ calBPtoF14C <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve
 #' @examples
 #'   calBPtopMC(100)
 #' @export
-calBPtopMC <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
-  y <- calBPtoC14(yr, cc, postbomb, rule, cc.dir, thiscurve)
+calBPtopMC <- function(x, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
+  y <- calBPtoC14(x, cc, postbomb, rule, cc.dir, thiscurve)
   return(C14topMC(y[,1], y[,2]))
 }
 
@@ -108,7 +108,7 @@ calBPtopMC <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding F14C value and error are returned.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For negative cal BP ages, a postbomb curve will have to be provided.
 #' @return The calibration-curve 14C year belonging to the entered cal BP age
-#' @param yr The cal BP year.
+#' @param x The cal BP year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
@@ -118,10 +118,10 @@ calBPtopMC <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=
 #' @examples
 #'   calBPtoD14C(100)
 #' @export
-calBPtoD14C <- function(yr, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
-  F <- calBPtoF14C(yr, cc, postbomb, rule, cc.dir, thiscurve)
-  Dmn <- F14CtoD14C(F[,1], t=yr)
-  Dup <- F14CtoD14C(F[,1]+F[,2], t=yr)
+calBPtoD14C <- function(x, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
+  F <- calBPtoF14C(x, cc, postbomb, rule, cc.dir, thiscurve)
+  Dmn <- F14CtoD14C(F[,1], t=x)
+  Dup <- F14CtoD14C(F[,1]+F[,2], t=x)
   return(cbind(Dmn, Dup-Dmn, deparse.level=0))
 }
 
@@ -155,7 +155,7 @@ BCADtocalBP <- function(x, zero=TRUE)
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding 14C age and error are returned. BC ages are negative. In this implementation, the year 0 BC/AD does exist.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For ages younger than AD 1950, a postbomb curve will have to be provided.
 #' @return The calibration-curve 14C year belonging to the entered BC/AD age
-#' @param yr The BC/AD year.
+#' @param x The BC/AD year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param zero Whether or not to include 0 in BC/AD years. Defaults to TRUE.
@@ -166,8 +166,8 @@ BCADtocalBP <- function(x, zero=TRUE)
 #' @examples
 #'   BCADtoC14(100)
 #' @export
-BCADtoC14 <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL, thiscurve=NULL) 
-  return(calBPtoC14(BCADtocalBP(yr, zero=zero), 
+BCADtoC14 <- function(x, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL, thiscurve=NULL) 
+  return(calBPtoC14(BCADtocalBP(x, zero=zero), 
     cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve))
 
 
@@ -177,7 +177,7 @@ BCADtoC14 <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL,
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding F14C and error are returned. BC ages are negative. In this implementation, the year 0 BC/AD does exist.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For ages younger than AD 1950, a postbomb curve will have to be provided.
 #' @return The calibration-curve F14C belonging to the entered BC/AD age
-#' @param yr The BC/AD year.
+#' @param x The BC/AD year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param zero Whether or not to include 0 in BC/AD years. Defaults to TRUE.
@@ -188,8 +188,8 @@ BCADtoC14 <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL,
 #' @examples
 #'   BCADtoF14C(100)
 #' @export
-BCADtoF14C <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL, thiscurve=NULL) 
-  return(calBPtoF14C(BCADtocalBP(yr, zero=zero), 
+BCADtoF14C <- function(x, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL, thiscurve=NULL) 
+  return(calBPtoF14C(BCADtocalBP(x, zero=zero), 
     cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve))
 
 
@@ -199,7 +199,7 @@ BCADtoF14C <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL,
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding pMC and error are returned. BC ages are negative. In this implementation, the year 0 BC/AD does exist.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For ages younger than AD 1950, a postbomb curve will have to be provided.
 #' @return The calibration-curve F14C belonging to the entered BC/AD age
-#' @param yr The BC/AD year.
+#' @param x The BC/AD year.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
 #' @param zero Whether or not to include 0 in BC/AD years. Defaults to TRUE.
@@ -210,9 +210,9 @@ BCADtoF14C <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL,
 #' @examples
 #'   BCADtopMC(100)
 #' @export
-BCADtopMC <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL, thiscurve=NULL) 
-    return(calBPtopMC(BCADtocalBP(yr, zero=zero), 
-      cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve))
+BCADtopMC <- function(x, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL, thiscurve=NULL) 
+  return(calBPtopMC(BCADtocalBP(x, zero=zero), 
+    cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve))
 
 
 
@@ -221,7 +221,7 @@ BCADtopMC <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL,
 #' @description Given a calendar age, the calibration curve (default cc=1) is interpolated and the corresponding F14C value and error are returned.
 #' @details Interpolation is used, and values outside the calibration curve are given as NA. For negative cal BP ages, a postbomb curve will have to be provided.
 #' @return The calibration-curve 14C year belonging to the entered cal BP age
-#' @param yr The cal BP year.
+#' @param x The cal BP year.
 #' @param zero Whether or not to include 0 in BC/AD years. Defaults to TRUE.
 #' @param cc calibration curve for C14 (see \code{caldist()}).
 #' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
@@ -232,35 +232,119 @@ BCADtopMC <- function(yr, cc=1, postbomb=FALSE, zero=TRUE, rule=1, cc.dir=NULL,
 #' @examples
 #'   BCADtoD14C(1900)
 #' @export
-BCADtoD14C <- function(yr, zero=TRUE, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
-  calBP <- BCADtocalBP(yr, zero)
+BCADtoD14C <- function(x, zero=TRUE, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
+  calBP <- BCADtocalBP(x, zero)
   Fres <- calBPtoF14C(calBP, cc=cc, postbomb=postbomb, rule=rule, cc.dir=cc.dir, thiscurve=thiscurve)
-  Dmn <- F14CtoD14C(Fres[,1], t=yr)
-  Dup <- F14CtoD14C(Fres[,1]+Fres[,2], t=yr)
+  Dmn <- F14CtoD14C(Fres[,1], t=x)
+  Dup <- F14CtoD14C(Fres[,1]+Fres[,2], t=x)
   return(cbind(Dmn, Dup-Dmn, deparse.level=0))
 }
 
 
 
+#' @name C14tocalBP
+#' @title Find the calBP age(s) crossing a C14 age.
+#' @description Find the cal BP ages where the calibration curve crosses a given C14 age. This function is for illustration only and not to be used for, e.g., calibration, because intercept calibration is an outdated method.
+#' @details. Whereas each cal BP age will only have one single IntCal radiocarbon age (mu), the same cannot be said for the other way round. Recurring C14 ages do happen, especially during periods of plateaux and wiggles. Therefore, there can be multiple cal BP ages for a single C14 age. In the early days, radiocarbon calibration used an 'intercept method' to find possible calendar ages belonging to a radiocarbon age, but this is problematic since small deviations in the C14 age can easily cause more or fewer crossing cal BP ages (try for example C14tocalBP(130) vs C14tocalBP(129)), and moreover, this approach does not deal well with the errors in either a date of the calibration curve. Therefore, the probabilistic approach to radiocarbon calibration (which starts with a cal BP age and then looks up the corresponding C14 age) has taken over as the standard.
+#' @return The cal BP age(s) belonging to the entered C14 age
+#' @param y The C14 age.
+#' @param cc calibration curve for C14 (see \code{caldist()}).
+#' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
+#' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
+#' @param cc.dir Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., \code{cc.dir="curves"}.
+#' @param thiscurve As an alternative to providing cc and/or postbomb, the data of a specific curve can be provided (3 columns: cal BP, C14 age, error).
+#' @author Maarten Blaauw
+#' @examples
+#'   y <- 130
+#'   calibrate(y,10)
+#'   abline(h=y)
+#'   abline(v=C14tocalBP(y))
+#' @export
+C14tocalBP <- function(y, cc=1, postbomb=FALSE, rule=1, cc.dir=NULL, thiscurve=NULL) {
+  if(is.null(thiscurve))
+    cc <- rintcal::ccurve(cc=cc, postbomb=postbomb, cc.dir=cc.dir) else
+      cc <- thiscurve
+  sel <- max(1, which(cc[,2] <= (y+2))) : min(nrow(cc), which(cc[,2] >= (y-2)))
+  cc <- cc[sel,] # only work with the relevant part of the calibration curve
+
+  interp <- function(i)
+    approx(cc[(i-1):i,2], cc[(i-1):i,1], y, rule=rule)$y
+
+  x <- c()
+  for(i in 2:nrow(cc))
+    if(cc[i-1,2] <= y && cc[i,2] > y) # crosses up
+      x <- c(x,interp(i)) else
+        if(cc[i-1,2] > y && cc[i,2] <= y) # crosses down
+          x <- c(x,interp(i))
+
+  return(x)
+}
+
+
+
+#' @name C14toBCAD
+#' @title Find the BCAD age(s) crossing a C14 age.
+#' @description Find the BCAD ages where the calibration curve crosses a given C14 age. This function is for illustration only and not to be used for, e.g., calibration, because intercept calibration is an outdated method.
+#' @return The BCAD age(s) belonging to the entered C14 age
+#' @details. Whereas each cal BP age will only have one single IntCal radiocarbon age (mu), the same cannot be said for the other way round. Recurring C14 ages do happen, especially during periods of plateaux and wiggles. Therefore, there can be multiple cal BP ages for a single C14 age. In the early days, radiocarbon calibration used an 'intercept method' to find possible calendar ages belonging to a radiocarbon age, but this is problematic since small deviations in the C14 age can easily cause more or fewer crossing cal BP ages (try for example C14tocalBP(130) vs C14tocalBP(129)), and moreover, this approach does not deal well with the errors in either a date of the calibration curve. Therefore, the probabilistic approach to radiocarbon calibration (which starts with a cal BP age and then looks up the corresponding C14 age) has taken over as the standard.
+#' @param y The C14 age.
+#' @param cc calibration curve for C14 (see \code{caldist()}).
+#' @param postbomb Whether or not to use a postbomb curve (see \code{caldist()}).
+#' @param rule How should R's approx function deal with extrapolation. If \code{rule=1}, the default, then NAs are returned for such points and if it is 2, the value at the closest data extreme is used.
+#' @param zero Whether or not to include 0 in BC/AD years. Defaults to TRUE.
+#' @param cc.dir Directory of the calibration curves. Defaults to where the package's files are stored (system.file), but can be set to, e.g., \code{cc.dir="curves"}.
+#' @param thiscurve As an alternative to providing cc and/or postbomb, the data of a specific curve can be provided (3 columns: cal BP, C14 age, error).
+#' @author Maarten Blaauw
+#' @examples
+#'   y <- 130
+#'   calibrate(y,10, BCAD=TRUE)
+#'   abline(h=y)
+#'   abline(v=C14toBCAD(y))
+#' @export
+C14toBCAD <- function(y, cc=1, postbomb=FALSE, rule=1, zero=TRUE, cc.dir=NULL, thiscurve=NULL) {
+  if(is.null(thiscurve))
+    cc <- rintcal::ccurve(cc=cc, postbomb=postbomb, cc.dir=cc.dir) else
+      cc <- thiscurve
+  sel <- max(1, which(cc[,2] <= (y+2))) : min(nrow(cc), which(cc[,2] >= (y-2)))
+  cc <- cc[sel,] # only work with the relevant part of the calibration curve
+
+  interp <- function(i)
+    approx(cc[(i-1):i,2], cc[(i-1):i,1], y, rule=rule)$y
+
+  x <- c()
+  for(i in 2:nrow(cc))
+    if(cc[i-1,2] <= y && cc[i,2] > y) # crosses up
+      x <- c(x,interp(i)) else
+        if(cc[i-1,2] > y && cc[i,2] <= y) # crosses down
+          x <- c(x,interp(i))
+
+  return(calBPtoBCAD(x, zero=zero))
+}
+
+
+
 #' @name C14toF14C
 #' @title Calculate F14C values from C14 ages
 #' @description Calculate F14C values from radiocarbon ages
 #' @details Post-bomb dates are often reported as F14C or fraction modern carbon. Since software such as Bacon expects radiocarbon ages,
 #' this function can be used to calculate F14C values from radiocarbon ages. The reverse function of \link{F14C.age}.
-#' @param mn Reported mean of the 14C age.
-#' @param sdev Reported error of the 14C age. If left empty, will translate mn to F14C.
+#' @param y Reported mean of the 14C age.
+#' @param er Reported error of the 14C age. If left empty, will translate y to F14C.
 #' @param decimals Amount of decimals required for the F14C value. Defaults to 5.
 #' @param lambda The mean-life of radiocarbon (based on Libby half-life of 5568 years)
 #' @return F14C values from C14 ages.
 #' @examples
 #'   C14toF14C(-2000, 20)
 #' @export
-C14toF14C <- function(mn, sdev=NULL, decimals=5, lambda=8033) {
-  y <- exp(-mn / lambda)
-  if(is.null(sdev))
-    return(signif(y, decimals)) else {
-      sdev <- y - exp(-(mn + sdev) / lambda)
-      return(signif(cbind(y, sdev, deparse.level=0), decimals))
+C14toF14C <- function(y, er=NULL, decimals=5, lambda=8033) {
+  fy <- exp(-y / lambda)
+  
+  if(is.null(er))
+    return(signif(fy, decimals)) else {
+      er1 <- exp(-(y - er) / lambda)
+      er2 <- exp(-(y + er) / lambda)
+      sdev <- abs(er1 - er2) / 2
+      return(signif(cbind(fy, sdev, deparse.level=0), decimals))
     }
 }
 
@@ -271,8 +355,8 @@ C14toF14C <- function(mn, sdev=NULL, decimals=5, lambda=8033) {
 #' @description Calculate pMC values from radiocarbon ages
 #' @details Post-bomb dates are often reported as pMC or percent modern carbon. Since Bacon expects radiocarbon ages,
 #' this function can be used to calculate pMC values from radiocarbon ages. The reverse function of \link{pMCtoC14}.
-#' @param mn Reported mean of the C14 age.
-#' @param sdev Reported error of the C14 age.
+#' @param y Reported mean of the C14 age.
+#' @param er Reported error of the C14 age.
 #' @param ratio Most modern-date values are reported against \code{100}. If it is against \code{1} instead, a warning is provided; use \code{C14.F14C}.
 #' @param decimals Amount of decimals required for the pMC value. Defaults to 5.
 #' @param lambda The mean-life of radiocarbon (based on Libby half-life of 5568 years)
@@ -281,13 +365,13 @@ C14toF14C <- function(mn, sdev=NULL, decimals=5, lambda=8033) {
 #'   C14topMC(-2000, 20)
 #'   C14topMC(-2000, 20, 1)
 #' @export
-C14topMC <- function(mn, sdev=NULL, ratio=100, decimals=5, lambda=8033) {
+C14topMC <- function(y, er=NULL, ratio=100, decimals=5, lambda=8033) {
   if(ratio !=100)
     warning("C14topMC expects a ratio of 100. For ratio=1, use C14toF14C")
-  y <- exp(-mn / lambda)
-  if(is.null(sdev))
+  y <- exp(-y / lambda)
+  if(is.null(er))
     return(signif(ratio*y, decimals)) else {
-      sdev <- y - exp(-(mn + sdev) / lambda)
+      sdev <- y - exp(-(y + er) / lambda)
       return(signif(ratio*cbind(y, sdev, deparse.level=0), decimals))
   }
 }
@@ -298,17 +382,17 @@ C14topMC <- function(mn, sdev=NULL, ratio=100, decimals=5, lambda=8033) {
 #' @title Transform C14 age(s) into D14C
 #' @details As explained by Heaton et al. 2020 (Radiocarbon), 14C measurements are commonly expressed in
 #' three domains: Delta14C, F14C and the radiocarbon age. This function translates C14 ages into Delta14C, the historical level of Delta14C in the year t cal BP. Note that per convention, this function uses the Cambridge half-life, not the Libby half-life.
-#' @param C14 The C14 age to translate
-#' @param sdev Reported error of the C14 age. Returns just the mean if left empty.
+#' @param y The C14 age to translate
+#' @param er Reported error of the C14 age. Returns just the mean if left empty.
 #' @param t the cal BP age
 #' @return The corresponding D14C value
 #' @examples
 #'   C14toD14C(0.985, 20, 222)
 #' @export
-C14toD14C <- function(C14, sdev=NULL, t) {
-  asF <- cbind(C14toF14C(C14, sdev))
+C14toD14C <- function(y, er=NULL, t) {
+  asF <- cbind(C14toF14C(y, er))
   Dmn <- 1000 * ((asF[,1] / exp(-t/8267)) - 1)
-  if(is.null(sdev))
+  if(is.null(er))
     return(Dmn) else {
 	  Fup <- asF[,1] + asF[,2]	
 	  Dup <- 1000 * ((Fup / exp(-t/8267)) - 1)
@@ -323,8 +407,8 @@ C14toD14C <- function(C14, sdev=NULL, t) {
 #' @description Calculate C14 ages from F14C values of radiocarbon dates.
 #' @details Post-bomb dates are often reported as F14C (between 0 at c. 55 kcal BP and 1 at c. AD 1950). Since software such as Bacon expects radiocarbon ages,
 #'  this function can be used to calculate radiocarbon ages from F14C values. The reverse function is \link{age.F14C}.
-#' @param mn Reported mean of the F14C
-#' @param sdev Reported error of the F14C. Returns just the mean if left empty.
+#' @param F14C Reported mean of the F14C
+#' @param er Reported error of the F14C. Returns just the mean if left empty.
 #' @param decimals Amount of decimals required for the radiocarbon age. Quite sensitive, defaults to 5.
 #' @param lambda The mean-life of radiocarbon (based on Libby half-life of 5568 years)
 #' @return The radiocarbon ages from the F14C values. If F14C values are above 100\%, the resulting radiocarbon ages will be negative.
@@ -332,11 +416,11 @@ C14toD14C <- function(C14, sdev=NULL, t) {
 #'   F14CtoC14(1.10, 0.5) # a postbomb date, so with a negative C14 age
 #'   F14CtoC14(.80, 0.5) # prebomb dates can also be calculated
 #' @export
-F14CtoC14 <- function(mn, sdev=NULL, decimals=5, lambda=8033) {
-  y <- -lambda * log(mn)
-  if(is.null(sdev))
+F14CtoC14 <- function(F14C, er=NULL, decimals=5, lambda=8033) {
+  y <- -lambda * log(F14C)
+  if(is.null(er))
     signif(y, decimals) else {
-    sdev <- y - -lambda * log((mn+sdev))
+    sdev <- y - -lambda * log((F14C+er))
     signif(cbind(y, sdev, deparse.level=0), decimals)
   }
 }
@@ -348,14 +432,14 @@ F14CtoC14 <- function(mn, sdev=NULL, decimals=5, lambda=8033) {
 #' @description Calculate pMC values from F14C values of radiocarbon dates.
 #' @details Post-bomb dates are often reported as F14C (between 0 at c. 55 kcal BP and 1 at c. AD 1950). Since software such as Bacon expects radiocarbon ages,
 #'  this function can be used to calculate radiocarbon ages from F14C values. The reverse function is \link{age.F14C}.
-#' @param mn Reported mean of the F14C
-#' @param sdev Reported error of the F14C. Returns just the mean if left empty.
+#' @param F14C Reported mean of the F14C
+#' @param er Reported error of the F14C. Returns just the mean if left empty.
 #' @return The pMC values from the F14C values. Basically the original values multiplied by 100.
 #' @examples
 #'   F14CtopMC(1.10, 0.5)
 #' @export
-F14CtopMC <- function(mn, sdev=NULL)
-  return(100*cbind(mn, sdev, deparse.level=0))
+F14CtopMC <- function(F14C, er=NULL)
+  return(100*cbind(F14C, er, deparse.level=0))
 
 
 
@@ -364,17 +448,17 @@ F14CtopMC <- function(mn, sdev=NULL)
 #' @details As explained by Heaton et al. 2020 (Radiocarbon), 14C measurements are commonly expressed in
 #' three domains: Delta14C, F14C and the radiocarbon age. This function translates F14C values into Delta14C, the historical level of Delta14C in the year t cal BP. Note that per convention, this function uses the Cambridge half-life, not the Libby half-life.
 #' @param F14C The F14C value to translate
-#' @param sdev Reported error of the F14C. Returns just the mean if left empty.
+#' @param er Reported error of the F14C. Returns just the mean if left empty.
 #' @param t the cal BP age
 #' @return The corresponding D14C value
 #' @examples
 #'   F14CtoD14C(0.89, .001, 900)
 #' @export
-F14CtoD14C <- function(F14C, sdev=NULL, t) {
+F14CtoD14C <- function(F14C, er=NULL, t) {
   Dmn <- 1000 * ((F14C / exp(-t/8267)) - 1)
-  if(is.null(sdev))
+  if(is.null(er))
     return(Dmn) else {
-      Dup <- 1000 * (((F14C+sdev) / exp(-t/8267)) - 1)
+      Dup <- 1000 * (((F14C+er) / exp(-t/8267)) - 1)
 	  return(cbind(Dmn, Dup-Dmn, deparse.level=0))
     }
 }
@@ -386,8 +470,8 @@ F14CtoD14C <- function(F14C, sdev=NULL, t) {
 #' @description Calculate C14 ages from pMC values of radiocarbon dates.
 #' @details Post-bomb dates are often reported as pMC or percent modern carbon. Since Bacon expects radiocarbon ages,
 #'  this function can be used to calculate radiocarbon ages from pMC values. The reverse function is C14.pMC.
-#' @param mn Reported mean of the pMC.
-#' @param sdev Reported error of the pMC.
+#' @param pMC Reported mean of the pMC.
+#' @param er Reported error of the pMC.
 #' @param ratio Most modern-date values are reported against \code{100}. If it is against \code{1} instead, use \code{1} here.
 #' @param decimals Amount of decimals required for the radiocarbon age.
 #' @param lambda The mean-life of radiocarbon (based on Libby half-life of 5568 years)
@@ -397,13 +481,13 @@ F14CtoD14C <- function(F14C, sdev=NULL, t) {
 #'   pMCtoC14(80, 0.5) # prebomb dates can also be calculated
 #'   pMCtoC14(.8, 0.005, ratio=1) # throws a warning, use F14C.age instead
 #' @export
-pMCtoC14 <- function(mn, sdev=NULL, ratio=100, decimals=0, lambda=8033) { 
+pMCtoC14 <- function(pMC, er=NULL, ratio=100, decimals=0, lambda=8033) { 
   if(ratio !=100)
     warning("pMCtoC14 expects a ratio of 100. For ratio=1, use F14CtoC14")
-  y <- -lambda * log(mn/ratio)
-  if(is.null(sdev))
+  y <- -lambda * log(pMC/ratio)
+  if(is.null(er))
     signif(y, decimals) else {
-    sdev <- y - -lambda * log((mn+sdev)/ratio)
+    sdev <- y - -lambda * log((pMC+er)/ratio)
     round(cbind(y, sdev, deparse.level=0), decimals)
   }
 }
@@ -415,14 +499,14 @@ pMCtoC14 <- function(mn, sdev=NULL, ratio=100, decimals=0, lambda=8033) {
 #' @description Calculate pMC values from F14C values of radiocarbon dates.
 #' @details Post-bomb dates are often reported as F14C (between 0 at c. 55 kcal BP and 1 at c. AD 1950). Since software such as Bacon expects radiocarbon ages,
 #'  this function can be used to calculate radiocarbon ages from F14C values. The reverse function is \link{age.F14C}.
-#' @param mn Reported mean of the F14C
-#' @param sdev Reported error of the pMC value. Returns just the mean if left empty.
+#' @param pMC Reported mean of the F14C
+#' @param er Reported error of the pMC value. Returns just the mean if left empty.
 #' @return The F14C values from the pMC values. Basically the original values divided by 100.
 #' @examples
 #'   pMCtoF14C(110, 5)
 #' @export
-pMCtoF14C <- function(mn, sdev=NULL)
-  return(cbind(mn, sdev, deparse.level=0)/100)
+pMCtoF14C <- function(pMC, er=NULL)
+  return(cbind(pMC, er, deparse.level=0)/100)
 
 
 
@@ -431,14 +515,14 @@ pMCtoF14C <- function(mn, sdev=NULL)
 #' @details As explained by Heaton et al. 2020 (Radiocarbon), 14C measurements are commonly expressed in
 #' three domains: Delta14C, F14C and the radiocarbon age. This function translates F14C values into Delta14C, the historical level of Delta14C in the year t cal BP. Note that per convention, this function uses the Cambridge half-life, not the Libby half-life.
 #' @param pMC The pMC value to translate
-#' @param sdev Reported error of the pMC value. Returns just the mean if left empty.
+#' @param er Reported error of the pMC value. Returns just the mean if left empty.
 #' @param t the cal BP age
 #' @return The corresponding D14C value
 #' @examples
 #'   pMCtoD14C(0.985, .1, 222)
 #' @export
-pMCtoD14C <- function(pMC, sdev=NULL, t) {
-  asF <- pMCtoF14C(pMC, sdev)	
+pMCtoD14C <- function(pMC, er=NULL, t) {
+  asF <- pMCtoF14C(pMC, er)	
   F14CtoD14C(asF[,1], asF[,2], t)
 }
 
@@ -448,14 +532,14 @@ pMCtoD14C <- function(pMC, sdev=NULL, t) {
 #' @details As explained by Heaton et al. 2020 (Radiocarbon), 14C measurements are commonly expressed in
 #' three domains: Delta14C, F14C and the radiocarbon age. This function translates Delta14C, the historical level of Delta14C in the year t cal BP, to C14 ages. Note that per convention, this function uses the Cambridge half-life, not the Libby half-life.
 #' @param D14C The Delta14C value to translate
-#' @param sdev Reported error of the D14C. Returns just the mean if left empty.
+#' @param er Reported error of the D14C. Returns just the mean if left empty.
 #' @param t the cal BP age
 #' @return The corresponding C14 age
 #' @examples
 #'   D14CtoC14(-10, 1, 238)
 #' @export
-D14CtoC14 <- function(D14C, sdev=NULL, t) {
-  return( F14CtoC14( D14CtoF14C(D14C=D14C, sdev=sdev, t=t) ))
+D14CtoC14 <- function(D14C, er=NULL, t) {
+  return( F14CtoC14( D14CtoF14C(D14C=D14C, er=er, t=t) ))
 }
 
 
@@ -465,17 +549,17 @@ D14CtoC14 <- function(D14C, sdev=NULL, t) {
 #' @details As explained by Heaton et al. 2020 (Radiocarbon), 14C measurements are commonly expressed in
 #' three domains: Delta14C, F14C and the radiocarbon age. This function translates Delta14C, the historical level of Delta14C in the year t cal BP, to F14C values. Note that per convention, this function uses the Cambridge half-life, not the Libby half-life.
 #' @param D14C The Delta14C value to translate
-#' @param sdev Reported error of the D14C. Returns just the mean if left empty.
+#' @param er Reported error of the D14C. Returns just the mean if left empty.
 #' @param t the cal BP age
 #' @return The corresponding F14C value
 #' @examples
 #'   D14CtoF14C(-10, 1, 238)
 #' @export
-D14CtoF14C <- function(D14C, sdev=NULL, t) {
+D14CtoF14C <- function(D14C, er=NULL, t) {
   asF <- ((D14C/1000)+1) * exp(-t/8267)
-  if(is.null(sdev))
+  if(is.null(er))
     return(asF) else {
-      Fup <- (((D14C+sdev)/1000)+1) * exp(-t/8267)
+      Fup <- (((D14C+er)/1000)+1) * exp(-t/8267)
 	  return(cbind(asF, Fup-asF, deparse.level=0))
     }
 }
@@ -487,14 +571,14 @@ D14CtoF14C <- function(D14C, sdev=NULL, t) {
 #' @details As explained by Heaton et al. 2020 (Radiocarbon), 14C measurements are commonly expressed in
 #' three domains: Delta14C, F14C and the radiocarbon age. This function translates Delta14C, the historical level of Delta14C in the year t cal BP, to F14C values. Note that per convention, this function uses the Cambridge half-life, not the Libby half-life.
 #' @param D14C The Delta14C value to translate
-#' @param sdev Reported error of the D14C. Returns just the mean if left empty.
+#' @param er Reported error of the D14C. Returns just the mean if left empty.
 #' @param t the cal BP age
 #' @return The corresponding F14C value
 #' @examples
 #'   D14CtoF14C(-10, 1, 238)
 #' @export
-D14CtopMC <- function(D14C, sdev=NULL, t) 
-  return(D14CtoF14C(D14C, sdev, t)/100)
+D14CtopMC <- function(D14C, er=NULL, t) 
+  return(D14CtoF14C(D14C, er, t)/100)
 
 
 
@@ -502,7 +586,7 @@ D14CtopMC <- function(D14C, sdev=NULL, t)
 
 #' @name pMC.age
 #' @title To be deprecated. Use pMCtoC14 instead.
-#' @description Will soon be deprecated. Use pMCtoC14 instead.
+#' @description Will be deprecated. Use pMCtoC14 instead.
 #' @details Post-bomb dates are often reported as pMC or percent modern carbon. Since Bacon expects radiocarbon ages,
 #'  this function can be used to calculate radiocarbon ages from pMC values. The reverse function is C14.pMC.
 #' @param mn Reported mean of the pMC.
@@ -514,7 +598,7 @@ D14CtopMC <- function(D14C, sdev=NULL, t)
 #' @export
 pMC.age <- function(mn, sdev=c(), ratio=100, decimals=0, lambda=8033) {
   message("pMC.age will be deprecated. Use pMCtoC14 instead") 
-  pMCtoC14(mn=mn, sdev=sdev, ratio=ratio, decimals=decimals, lambda=lambda)
+  pMCtoC14(mn, sdev, ratio, decimals, lambda)
 }
 
 
@@ -533,7 +617,7 @@ pMC.age <- function(mn, sdev=c(), ratio=100, decimals=0, lambda=8033) {
 #' @export
 age.pMC <- function(mn, sdev=c(), ratio=100, decimals=5, lambda=8033) {
   message("age.pMC will be deprecated. Use C14topMC instead") 	
-  C14topMC(mn=mn, sdev=sdev, ratio=ratio, decimals=decimals, lambda=lambda)
+  C14topMC(mn, sdev, ratio, decimals, lambda)
 }
 
 
@@ -551,7 +635,7 @@ age.pMC <- function(mn, sdev=c(), ratio=100, decimals=5, lambda=8033) {
 #' @export
 F14C.age <- function(mn, sdev=c(), decimals=5, lambda=8033) {
   message("F14C.age will be deprecated. Use F14CtoC14 instead")
-  F14CtoC14(mn=mn, sdev=sdev, decimals=decimals, lambda=lambda)
+  F14CtoC14(mn, sdev, decimals, lambda)
 }
 
 
@@ -569,6 +653,6 @@ F14C.age <- function(mn, sdev=c(), decimals=5, lambda=8033) {
 #' @export
 age.F14C <- function(mn, sdev=c(), decimals=5, lambda=8033) {
   message("age.F14C will be deprecated. Use C14toF14C instead") 	
-  C14toF14C(mn=mn, sdev=sdev, decimals=decimals, lambda=lambda)
+  C14toF14C(mn, sdev, decimals, lambda)
 }
 
